#!/bin/bash

# INTELLECTUAL PROPERTY RIGHT STATEMENT
# 
# The original source material is obtained from Christophe Seux, Class room,
# Blender project, url: https://www.blender.org/download/demo-files/, and 
# according to that website, the Classroom material is subject to the CC0 
# license.
# 
# That source material has been processed by Philips. As regards the processed
# material, and the way the processed material is obtained from the source 
# material, intellectual property rights are owned by Koninklijke Philips N.V. 
# These processed materials may only be used for the purpose of developing,
# testing and promulgating technology standards as well as for academic 
# purposes. Koninklijke Philips N.V. makes no warranties with respect to the 
# processed materials and the processing method, and expressly disclaims any 
# warranties regarding their fitness for any purpose.

trap exit ERR

# NOTE: Install Git for Windowes with command-line tools to run this file in Windows
#       export blender=/c/Program\ Files/Blender\ Foundation/Blender/blender.exe
#       bash ClassroomVideo_raytrace.sh
blender=${blender:-blender}

# The file with the camera parameters
export camparamsfile=ClassroomVideo.json

# The camera of which to take the position
export viewid=v14

# Specify the number of threads for Blender
export nthreads=16

# Specify the number of samples per pixel (use 1 for depth)
export nsamples=100

# How many frames to render
export nframes=1

# Download the original Class room scene
# NOTE: On Windows just download manually
[ -f classroom.zip ] || wget https://download.blender.org/demo/test/classroom.zip

# Unpack the archive (once)
[ -d classroom ] || unzip classroom.zip

# Transform the original scene
"$blender" --background classroom/classroom.blend --python ClassroomVideo_transform.py

# NOTE: The idea is to split frames over multiple compute nodes
for ((frame = 1; frame <= 300; ++frame))
do
	"$blender" --background classroom/ClassroomVideo_${viewid}_${nsamples}spp.blend --render-frame $nframes
done 
